============
Contributing
============

Satori's code is hosted on `GitHub`_. Our development process follows the
`OpenStack Gerrit`_ workflow which is much different than most projects on
Github.

If you find a problem, please `file a bug`_. Feature additions and design
discussions are taking place in `blueprints`_. `Reviewing code`_ is an easy way
to start contributing.

.. _OpenStack Gerrit: https://wiki.openstack.org/wiki/Gerrit_Workflow
.. _GitHub: https://github.com/stackforge/satori
.. _file a bug: https://bugs.launchpad.net/satori
.. _blueprints: https://blueprints.launchpad.net/satori
.. _Reviewing code: https://review.openstack.org/#/q/status:open+project:stackforge/satori,n,z
